@@ -9,7 +9,7 @@
 use eyre::{Context, Result};
 use safe_network::{
     client::{utils::test_utils::read_network_conn_info, Client, Config},
-    url::{ContentType, NativeUrl, Scope, DEFAULT_XORURL_BASE},
+    url::{ContentType, Scope, Url, DEFAULT_XORURL_BASE},
 };
 use std::{
     io::{stdout, Write},
@@ -36,7 +36,7 @@ async fn main() -> Result<()> {
     println!("Storing data on Blob: {}", raw_data);
 
     let address = client.store_public_blob(raw_data.as_bytes()).await?;
-    let xorurl = NativeUrl::encode_blob(
+    let xorurl = Url::encode_blob(
         *address.name(),
         Scope::Public,
         ContentType::Raw,
